@@ -1,17 +1,17 @@
 static const char *petscmachineinfo = "\n"
 "-----------------------------------------\n"
-"Libraries compiled on 2025-04-09 06:27:57 on reproducible\n"
-"Machine characteristics: MINGW64_NT-10.0-22631-ARM64-3.5.7-2644508f.x86_64-x86_64-64bit-WindowsPE\n"
-"Using PETSc directory: /c/M/B/src/build-CLANGARM64/petsc-3.23.0\n"
+"Libraries compiled on 2025-06-29 11:35:32 on reproducible\n"
+"Machine characteristics: MINGW64_NT-10.0-22631-ARM64-3.6.3-bc3e285a.x86_64-x86_64-64bit-WindowsPE\n"
+"Using PETSc directory: /c/W/B/src/build-CLANGARM64/petsc-3.23.3\n"
 "Using PETSc arch: cso\n"
 "-----------------------------------------\n";
 static const char *petsccompilerinfo = "\n"
 "Using C compiler: clang -O2 -pipe -Wp,-D_FORTIFY_SOURCE=2 -fstack-protector-strong -Wp,-D__USE_MINGW_ANSI_STDIO=1 -Wno-incompatible-function-pointer-types -fPIC \n"
 "-----------------------------------------\n";
 static const char *petsccompilerflagsinfo = "\n"
-"Using include paths: -I/c/M/B/src/build-CLANGARM64/petsc-3.23.0/include -I/c/M/B/src/build-CLANGARM64/petsc-3.23.0/cso/include -I/clangarm64/include\n"
+"Using include paths: -I/c/W/B/src/build-CLANGARM64/petsc-3.23.3/include -I/c/W/B/src/build-CLANGARM64/petsc-3.23.3/cso/include -I/clangarm64/include\n"
 "-----------------------------------------\n";
 static const char *petsclinkerinfo = "\n"
 "Using C linker: clang\n"
-"Using libraries: -Wl,-rpath,/c/M/B/src/build-CLANGARM64/petsc-3.23.0/cso/lib -L/c/M/B/src/build-CLANGARM64/petsc-3.23.0/cso/lib -lpetsc -Wl,-rpath,/clangarm64/lib -L/clangarm64/lib -lopenblas -lregex -lhwloc -lgdi32 -luser32 -ladvapi32 -lkernel32\n"
+"Using libraries: -Wl,-rpath,/c/W/B/src/build-CLANGARM64/petsc-3.23.3/cso/lib -L/c/W/B/src/build-CLANGARM64/petsc-3.23.3/cso/lib -lpetsc -Wl,-rpath,/clangarm64/lib -L/clangarm64/lib -lopenblas -lhwloc -lgdi32 -luser32 -ladvapi32 -lkernel32\n"
 "-----------------------------------------\n";
