@@ -14,7 +14,7 @@
 #define PETSC_DEPRECATED_MACRO_BASE_(why) _Pragma(#why)
 #define PETSC_DEPRECATED_OBJECT_BASE(string_literal_why) __attribute__((deprecated(string_literal_why)))
 #define PETSC_DEPRECATED_TYPEDEF_BASE(string_literal_why) __attribute__((deprecated(string_literal_why)))
-#define PETSC_DIR "/c/M/B/src/build-CLANGARM64/petsc-3.23.0"
+#define PETSC_DIR "/c/W/B/src/build-CLANGARM64/petsc-3.23.3"
 #define PETSC_DIR_SEPARATOR '/'
 #define PETSC_FUNCTION_NAME_C __func__
 #define PETSC_HAVE_ACCESS 1
@@ -59,11 +59,10 @@
 #define PETSC_HAVE_OPENBLAS 1
 #define PETSC_HAVE_OPENBLAS_SET_NUM_THREADS 1
 #define PETSC_HAVE_O_BINARY 1
-#define PETSC_HAVE_PACKAGES ":blaslapack:hwloc:mathlib:mpi:openblas:regex:"
+#define PETSC_HAVE_PACKAGES ":blaslapack:hwloc:mathlib:mpi:openblas:"
 #define PETSC_HAVE_POPEN 1
 #define PETSC_HAVE_RAND 1
 #define PETSC_HAVE_REAL___FP16 1
-#define PETSC_HAVE_REGEX 1
 #define PETSC_HAVE_SETJMP_H 1
 #define PETSC_HAVE_SETLASTERROR 1
 #define PETSC_HAVE_SLEEP 1
@@ -101,7 +100,7 @@
 #define PETSC_IS_COLORING_VALUE_TYPE short
 #define PETSC_IS_COLORING_VALUE_TYPE_F integer2
 #define PETSC_LEVEL1_DCACHE_LINESIZE 32
-#define PETSC_LIB_DIR "/c/M/B/src/build-CLANGARM64/petsc-3.23.0/dso/lib"
+#define PETSC_LIB_DIR "/c/W/B/src/build-CLANGARM64/petsc-3.23.3/dso/lib"
 #define PETSC_LIB_NAME_SUFFIX ""
 #define PETSC_MAX_PATH_LEN 260
 #define PETSC_MEMALIGN 16
